@@ -1,6 +1,6 @@
 '''The Nester Module'''
 
-def print_lol(l, level):
+def print_lol(l, level=0):
     '''Function that prints a given list recursively with indentation'''
     for item in l:
         if isinstance(item, list):
